@@ -94,7 +94,7 @@ e_mapi_tm_to_icaltimetype (struct tm *tm,
 	itt.month = dst ? 6 : 1;
 	itt.year = tm->tm_year + 1900;
 
-	itt.is_utc = 0;
+	itt.zone = NULL;
 	itt.is_date = 0;
 
 	return itt;
